@@ -5,11 +5,12 @@ mod servers;
 use crate::config::Config;
 use crate::servers::Server;
 
-use std::env;
 use log::{debug, error};
+use std::env;
 
 fn main() {
-    let config_path = env::var("FOURTH_CONFIG").unwrap_or_else(|_| "/etc/fourth/config.yaml".to_string());
+    let config_path =
+        env::var("FOURTH_CONFIG").unwrap_or_else(|_| "/etc/fourth/config.yaml".to_string());
 
     let config = match Config::new(&config_path) {
         Ok(config) => config,
@@ -23,6 +24,6 @@ fn main() {
     let mut server = Server::new(config.base);
     debug!("{:?}", server);
 
-    let res = server.run();
-    error!("Server returned an error: {:?}", res);
+    let _ = server.run();
+    error!("Server ended with errors");
 }
